==> estateplat-common-1.2.4-20210301.011821-660-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxYhCqxx.java <==
package cn.gtmap.estateplat.model.exchange.share;
/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/5/26
 * @description 银行抵押信息
 */

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

@Table(name = "gx_yh_cqxx")
public class GxYhCqxx implements Serializable{


    @Id
    private String qlid;//权利id
    private String gyfs;//共有方式
    private String ywid;//业务信息id
    private String bdcdyh;//不动产单元号
    private String fczh;//房产证号
    private String tdzh;//土地证号
    private String lrzh;//录入证号
    private Date tdsyksqx;//土地使用开始期限
    private Date tdsyjsqx;//土地使用结束期限
    private String ghyt;//规划用途
    private String ghytmc;//规划用途名称
    private String tdyt;//土地用途
    private String tdytmc;//土地用途名称
    private String zl;//坐落
    private String fdcjyhth;//房地产交易合同号
    private Double jzmj;//建筑面积
    private Double fttdmj;//土地分摊面积
    private Double fdcjyjg;//房地产交易价格
    private String bz;//备注
    private String fj;//备注
    private Date basj;//备案时间
    private Integer xzzrnx;//限制转让年限
    private String djyy;//登记原因
    private String djzx;//登记子项
    private String lrzhqlid;//录入证号qlid
    private String sfhcdzzz;//是否合成电子证照

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getDjzx() {
        return djzx;
    }

    public void setDjzx(String djzx) {
        this.djzx = djzx;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getFczh() {
        return fczh;
    }

    public void setFczh(String fczh) {
        this.fczh = fczh;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public String getLrzh() {
        return lrzh;
    }

    public void setLrzh(String lrzh) {
        this.lrzh = lrzh;
    }

    public Date getTdsyksqx() {
        return tdsyksqx;
    }

    public void setTdsyksqx(Date tdsyksqx) {
        this.tdsyksqx = tdsyksqx;
    }

    public Date getTdsyjsqx() {
        return tdsyjsqx;
    }

    public void setTdsyjsqx(Date tdsyjsqx) {
        this.tdsyjsqx = tdsyjsqx;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getGhytmc() {
        return ghytmc;
    }

    public void setGhytmc(String ghytmc) {
        this.ghytmc = ghytmc;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getTdytmc() {
        return tdytmc;
    }

    public void setTdytmc(String tdytmc) {
        this.tdytmc = tdytmc;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFdcjyhth() {
        return fdcjyhth;
    }

    public void setFdcjyhth(String fdcjyhth) {
        this.fdcjyhth = fdcjyhth;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Double getFdcjyjg() {
        return fdcjyjg;
    }

    public void setFdcjyjg(Double fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Date getBasj() {
        return basj;
    }

    public void setBasj(Date basj) {
        this.basj = basj;
    }

    public Integer getXzzrnx() {
        return xzzrnx;
    }

    public void setXzzrnx(Integer xzzrnx) {
        this.xzzrnx = xzzrnx;
    }

    public String getLrzhqlid() {
        return lrzhqlid;
    }

    public void setLrzhqlid(String lrzhqlid) {
        this.lrzhqlid = lrzhqlid;
    }

    public String getSfhcdzzz() {
        return sfhcdzzz;
    }

    public void setSfhcdzzz(String sfhcdzzz) {
        this.sfhcdzzz = sfhcdzzz;
    }
}

==> estateplat-common-1.2.4-20210430.022517-740-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxYhCqxx.java <==
package cn.gtmap.estateplat.model.exchange.share;
/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/5/26
 * @description 银行抵押信息
 */

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

@Table(name = "gx_yh_cqxx")
public class GxYhCqxx implements Serializable{


    @Id
    private String qlid;//权利id
    private String gyfs;//共有方式
    private String ywid;//业务信息id
    private String bdcdyh;//不动产单元号
    private String fczh;//房产证号
    private String tdzh;//土地证号
    private String lrzh;//录入证号
    private Date tdsyksqx;//土地使用开始期限
    private Date tdsyjsqx;//土地使用结束期限
    private String ghyt;//规划用途
    private String ghytmc;//规划用途名称
    private String tdyt;//土地用途
    private String tdytmc;//土地用途名称
    private String zl;//坐落
    private String fdcjyhth;//房地产交易合同号
    private Double jzmj;//建筑面积
    private Double fttdmj;//土地分摊面积
    private Double fdcjyjg;//房地产交易价格
    private String bz;//备注
    private String fj;//备注
    private Date basj;//备案时间
    private Integer xzzrnx;//限制转让年限
    private String djyy;//登记原因
    private String djzx;//登记子项
    private String lrzhqlid;//录入证号qlid
    private String sfhcdzzz;//是否合成电子证照
    private String tdsyqz;//土地使用权证

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getDjzx() {
        return djzx;
    }

    public void setDjzx(String djzx) {
        this.djzx = djzx;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getFczh() {
        return fczh;
    }

    public void setFczh(String fczh) {
        this.fczh = fczh;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public String getLrzh() {
        return lrzh;
    }

    public void setLrzh(String lrzh) {
        this.lrzh = lrzh;
    }

    public Date getTdsyksqx() {
        return tdsyksqx;
    }

    public void setTdsyksqx(Date tdsyksqx) {
        this.tdsyksqx = tdsyksqx;
    }

    public Date getTdsyjsqx() {
        return tdsyjsqx;
    }

    public void setTdsyjsqx(Date tdsyjsqx) {
        this.tdsyjsqx = tdsyjsqx;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getGhytmc() {
        return ghytmc;
    }

    public void setGhytmc(String ghytmc) {
        this.ghytmc = ghytmc;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getTdytmc() {
        return tdytmc;
    }

    public void setTdytmc(String tdytmc) {
        this.tdytmc = tdytmc;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFdcjyhth() {
        return fdcjyhth;
    }

    public void setFdcjyhth(String fdcjyhth) {
        this.fdcjyhth = fdcjyhth;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Double getFdcjyjg() {
        return fdcjyjg;
    }

    public void setFdcjyjg(Double fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Date getBasj() {
        return basj;
    }

    public void setBasj(Date basj) {
        this.basj = basj;
    }

    public Integer getXzzrnx() {
        return xzzrnx;
    }

    public void setXzzrnx(Integer xzzrnx) {
        this.xzzrnx = xzzrnx;
    }

    public String getLrzhqlid() {
        return lrzhqlid;
    }

    public void setLrzhqlid(String lrzhqlid) {
        this.lrzhqlid = lrzhqlid;
    }

    public String getSfhcdzzz() {
        return sfhcdzzz;
    }

    public void setSfhcdzzz(String sfhcdzzz) {
        this.sfhcdzzz = sfhcdzzz;
    }

    public String getTdsyqz() {
        return tdsyqz;
    }

    public void setTdsyqz(String tdsyqz) {
        this.tdsyqz = tdsyqz;
    }
}
